<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sr">
<context>
    <name>GrandSearch::AiToolBar</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="48"/>
        <source>Unable to use %1, please go to the App Store to update the UOS AI version first.</source>
        <translation>Немогу да користим %1, молимо вас да отидете у Ап Сторе да бисте ажурирали верзију UOS AI прво.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="49"/>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="50"/>
        <source>Open App Stroe</source>
        <translation>Отвори Ап Сторе</translation>
    </message>
</context>
<context>
    <name>GrandSearch::AiToolBarInner</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="112"/>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="162"/>
        <source>Summary</source>
        <translation>Сумаризација</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="113"/>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="163"/>
        <source>Translation</source>
        <translation>Превод</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="114"/>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="164"/>
        <source>Extension</source>
        <translation>Продужење</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="115"/>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="165"/>
        <source>Add to knowledge base</source>
        <translation>Додај у знање базу</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="126"/>
        <source>Summarize document content with UOS AI</source>
        <translation>Сумаризујте садржај документа са UOS AI</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="127"/>
        <source>Translate document content with UOS AI</source>
        <translation>Преведите садржај документа са UOS AI</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="128"/>
        <source>Extend document content with UOS AI</source>
        <translation>Продужите садржај документа са UOS AI</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="129"/>
        <source>Add document to UOS AI knowledge base</source>
        <translation>Додајте документ у знање базу UOS AI</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="299"/>
        <source>Summarize this document for me and provide me with a clear result directly, without any unnecessary content.</source>
        <translation>Сумаризујте овај документ за мене и направите ми јасан резултат директно, без неопходних података.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="315"/>
        <source>Translate this document for me and provide me with a clear result directly, without any unnecessary content.</source>
        <translation>Преведите овај документ за мене и направите ми јасан резултат директно, без неопходних података.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="331"/>
        <source>Expand this document for me and provide me with a clear and expanded result directly, without any unnecessary content.</source>
        <translation>Расшифрујте овај документ за мене и направите ми јасан и расширен резултат директно, без неопходних података.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="447"/>
        <source>DDE Grand Search</source>
        <translation>ДДЕ Гранд Срч</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="450"/>
        <source>Unable to use %1, please go to the App Store to update the UOS AI version first.</source>
        <translation>Немогу да користим %1, молимо вас да отидете у Ап Сторе да бисте ажурирали верзију UOS AI прво.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/aitoolbar.cpp" line="451"/>
        <source>Open App Stroe</source>
        <translation>Отвори Ап Сторе</translation>
    </message>
</context>
<context>
    <name>GrandSearch::BestMatchWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/bestmatchwidget.cpp" line="28"/>
        <source>Best match</source>
        <translation>Најбољи подударање</translation>
    </message>
</context>
<context>
    <name>GrandSearch::BlackListWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/blacklistwidget.cpp" line="32"/>
        <source>Excluded path</source>
        <translation>Искључени пут</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/blacklistwidget.cpp" line="43"/>
        <source>Add paths to the exclusion list to prevent searching in them.</source>
        <translation>Додајте путеве у листу искључења да бисте спречили претрагу у њима.</translation>
    </message>
</context>
<context>
    <name>GrandSearch::CustomWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/customwidget.cpp" line="31"/>
        <source>Custom search</source>
        <translation>Прилагођена претрага</translation>
    </message>
</context>
<context>
    <name>GrandSearch::DdeGrandSearchDockPlugin</name>
    <message>
        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="49"/>
        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="122"/>
        <source>Grand Search</source>
        <translation>Гранд Срч</translation>
    </message>
    <message>
        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="201"/>
        <source>Search settings</source>
        <translation type="unfinished">Подешавање претраге</translation>
    </message>
</context>
<context>
    <name>GrandSearch::DeleteDialog</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/blacklistview/deletedialog.cpp" line="14"/>
        <source>Do you want to remove the path from the exclusion list?</source>
        <translation>Желите ли да уклоните пут из листе искључења?</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/blacklistview/deletedialog.cpp" line="20"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Откажи</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/blacklistview/deletedialog.cpp" line="28"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Потврди</translation>
    </message>
</context>
<context>
    <name>GrandSearch::EmbeddingPluginWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/embeddingpluginwidget.cpp" line="52"/>
        <source>Installed</source>
        <translation>Инсталирано</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/embeddingpluginwidget.cpp" line="52"/>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/embeddingpluginwidget.cpp" line="90"/>
        <source>Not Installed</source>
        <translation>Не инсталирано</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/embeddingpluginwidget.cpp" line="105"/>
        <source>Install</source>
        <translation>Инсталирај</translation>
    </message>
</context>
<context>
    <name>GrandSearch::EntranceWidget</name>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="237"/>
        <source>Search</source>
        <translation type="unfinished">Претражи</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="238"/>
        <source>What would you like to search for?</source>
        <translation type="unfinished">Шта желите да претражите?</translation>
    </message>
</context>
<context>
    <name>GrandSearch::EntranceWidgetPrivate</name>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="82"/>
        <source>Cut</source>
        <translation type="unfinished">Исеци</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="86"/>
        <source>Copy</source>
        <translation type="unfinished">Копирај</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="90"/>
        <source>Paste</source>
        <translation type="unfinished">Убаци</translation>
    </message>
</context>
<context>
    <name>GrandSearch::GeneralPreviewPlugin</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalpreviewplugin.cpp" line="193"/>
        <source>Location:</source>
        <translation type="unfinished">Локација:</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalpreviewplugin.cpp" line="204"/>
        <source>Time modified:</source>
        <translation type="unfinished">Измењено:</translation>
    </message>
</context>
<context>
    <name>GrandSearch::GeneralToolBar</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="70"/>
        <source>Open</source>
        <translation type="unfinished">Покрени</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="75"/>
        <source>Open Path</source>
        <translation type="unfinished">Отвори путању</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="80"/>
        <source>Copy Path</source>
        <translation type="unfinished">Копирај путању</translation>
    </message>
</context>
<context>
    <name>GrandSearch::GroupWidget</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="269"/>
        <source>Please go to %1 to install the ULLM, and %2 Automatic index update.</source>
        <translation>Молимо вас да отидете на %1 да бисте инсталирали ULLM, и %2 Аутоматско ажурирање индекса.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="270"/>
        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="279"/>
        <source>Search configration</source>
        <translation>Претрага конфигурација</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="271"/>
        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="275"/>
        <source>turn on</source>
        <translation>Укључи</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="274"/>
        <source>Please %1 Automatic index update.</source>
        <translation>Молимо %1 аутоматско ажурирање индекса.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="278"/>
        <source>Please go to %1 to install the ULLM.</source>
        <translation>Молимо појавите се на %1 да бисте инсталирали ULLM.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="330"/>
        <source>More</source>
        <translation type="unfinished">Више</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="281"/>
        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="366"/>
        <source>No search results</source>
        <translation type="unfinished">Нема резултата претраге</translation>
    </message>
</context>
<context>
    <name>GrandSearch::IndexWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/indexwidget.cpp" line="30"/>
        <source>Index</source>
        <translation>Индекс</translation>
    </message>
</context>
<context>
    <name>GrandSearch::IntelligentRetrievalWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="66"/>
        <source>AI Smart Search</source>
        <translation>AI Смарт Сearch</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="79"/>
        <source>When turned on, you can try to search for local documents using natural language descriptions, such as &quot;last week&apos;s documents&quot;.</source>
        <translation>Када је укључено, можете покушати да претражите локалне докумете коришћењем природних језичних описа, као што је &quot;документи из прошле недеље&quot;.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="100"/>
        <source>Automatic index update</source>
        <translation>Аутоматско ажурирање индекса</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="119"/>
        <source>Full Text Search</source>
        <translation>Пунотекстни претрага</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="136"/>
        <source>When turned on, full text search can be used in the file manager and grand search.</source>
        <translation>Када је укључено, пунотекстна претрага се може користити у управљачу датотекама и grand search.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="154"/>
        <source>Embedding Plugins</source>
        <translation>Плагини за ембедовање</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="154"/>
        <source>After installing the model, you can use services such as AI Search and UOS AI Assistant..</source>
        <translation>Након инсталирања модела, можете користити услуге као што су AI Претрага и UOS AI Асистент.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="172"/>
        <source>ULLM</source>
        <translation>ULLM</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="172"/>
        <source>After installing the ULLM, you can use the AI intelligent search function without an internet connection.</source>
        <translation>Након инсталирања ULLM, можете користити AI интелигентну претрагу без интернета.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="185"/>
        <source>Intelligent full text search</source>
        <translation>Интелигентна пунотекстна претрага</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="221"/>
        <source>When enabled, you can search the text of articles using disjointed and incomplete keywords.</source>
        <translation>Када је омогућено, можете претраживати текст чланака коришћењем несавршених и непотпуних кључних речи.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="243"/>
        <source>Please install %0 in &lt;a href=&quot;%0&quot;&gt;the app store&lt;/a&gt; before turning on this configuration.</source>
        <translation>Молимо инсталирајте %0 у &lt;a href=&quot;%0&quot;&gt;апликационом тргу&lt;/a&gt; пре него што укључите ову конфигурацију.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="283"/>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="407"/>
        <source>Intelligent search indexing is being updated, which may take up more resources, please keep the power access.</source>
        <translation>Интелигентно индексирање претраге се ажурира, што може да захтева више ресурса, молимо вас задржите приступ енергији.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="287"/>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="411"/>
        <source>Smart Search indexing update is complete. Last update time: %0</source>
        <translation>Ажурирање индекса за Smart Search је завршено. Последња датум ажурирања: %0</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="290"/>
        <source>Indexing error!</source>
        <translation>Грешка при индексирању!</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="339"/>
        <source>To use AI Smart Search, you need to install the Embedding Plugins and ULLM first.</source>
        <translation>За коришћење AI Смарт Сearch, прво морате инсталирати Плагине за ембедовање и ULLM.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/intelligentretrieval/intelligentretrievalwidget.cpp" line="340"/>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
</context>
<context>
    <name>GrandSearch::LLMWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="61"/>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="385"/>
        <source>Not Installed</source>
        <translation>Не инсталиран</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="77"/>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="384"/>
        <source>Install Model</source>
        <translation>Инсталирај модел</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="93"/>
        <source>Update model</source>
        <translation>Ажурирај модел</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="94"/>
        <source>Uninstall model</source>
        <translation>Деинсталирај модел</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="146"/>
        <source>Installing</source>
        <translation>Инсталирање</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="212"/>
        <source>Are you sure you want to delete this model?</source>
        <translation>Сигурни сте да желите да обришете овај модел?</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="213"/>
        <source>After uninstallation, functions such as AI Search and UOS AI Assistant will not work properly.</source>
        <translation>Након деинсталирања, функције као што су AI Претрага и UOS AI Асистент неће радити исправно.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="214"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Поништи</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="215"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Потврди</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="324"/>
        <source>Installing </source>
        <translation>Инсталирање </translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="344"/>
        <source>Installing the ULLM</source>
        <translation>Инсталирање ULLM</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="345"/>
        <source>Exiting will cause the installation to fail, do you still want to exit?</source>
        <translation>Излазак ће довести до неуспеха инсталирања, да ли желите да изашете?</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="346"/>
        <source>Exit</source>
        <comment>button</comment>
        <translation>Излаз</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="347"/>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Настави</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="378"/>
        <source>UnInstall Model</source>
        <translation>Деинсталирај модел</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="379"/>
        <source>Installed</source>
        <translation>Инсталирано</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/llmwidget/llmwidget.cpp" line="390"/>
        <source>Please install the &quot;Embedding Plugins&quot; first before installing this model.</source>
        <translation>Молимо вас, прво инсталирајте „Embedding Plugins“, па онда инсталирате овај модел.</translation>
    </message>
</context>
<context>
    <name>GrandSearch::MainWindow</name>
    <message>
        <location filename="../src/grand-search/gui/mainwindow.cpp" line="222"/>
        <source>No search results</source>
        <translation type="unfinished">Нема резултата претраге</translation>
    </message>
</context>
<context>
    <name>GrandSearch::MatchWidget</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/matchresult/matchwidget.cpp" line="89"/>
        <source>Guess you want to search the following</source>
        <translation>Па разумејте да желите да претражите следеће</translation>
    </message>
</context>
<context>
    <name>GrandSearch::PlanWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="32"/>
        <source>Search experience program</source>
        <translation type="unfinished">Програм за искуство претраживања</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="40"/>
        <source>Join search experience program</source>
        <translation type="unfinished">Придружи се програму за искуство претраживања</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="53"/>
        <source>Joining the search experience program means that you grant and authorize us to collect the information of your device and system, file icons, content and properties, applications and their configurations, the contents you search while using the Application, the time of search, the type of requested large model.If you refuse our collection and use of the aforementioned information, do not join the program.</source>
        <translation>Пријава на програм за искуство претраге значи да вам дозволимо и одобримо да прикупимо информације о вашем уређају и систему, иконама датотека, садржају и својинама, апликацијама и њиховим конфигурацијама, садржајима које претражите док користите Апликацију, времену претраге, и типу захтеваног великог модела. Ако одбијете прикупљање и коришћење наведених информација, не пријавите се у програм.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="64"/>
        <source>To know more about the management of your data, please refer to the UnionTech Software Privacy Policy (</source>
        <translation type="unfinished">Да сазнате више о управљању вашим подацима, молимо прочитајте UnionTech политику приватности (</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="66"/>
        <source>https://www.uniontech.com/agreement/privacy-en</source>
        <translation type="unfinished">https://www.uniontech.com/agreement/privacy-en</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="67"/>
        <source>https://www.deepin.org/en/agreement/privacy/</source>
        <translation type="unfinished">https://www.deepin.org/en/agreement/privacy/</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="69"/>
        <source>).</source>
        <translation type="unfinished">).</translation>
    </message>
</context>
<context>
    <name>GrandSearch::ScopeWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/scopewidget.cpp" line="33"/>
        <source>Search contents</source>
        <translation type="unfinished">Претражи конткте</translation>
    </message>
</context>
<context>
    <name>GrandSearch::SearchEngineWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="42"/>
        <source>Default search engine</source>
        <translation>Подразумети претраживач</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="50"/>
        <source>Search for keywords by the default search engine.</source>
        <translation>Претражите кључне речи коришћењем подразуметог претраживача.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="62"/>
        <source>Default search engine is</source>
        <translation>Подразумети претраживач је</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="71"/>
        <source>Google</source>
        <translation>Google</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="72"/>
        <source>Baidu</source>
        <translation>Baidu</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="73"/>
        <source>Bing</source>
        <translation>Bing</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="74"/>
        <source>Yahoo</source>
        <translation>Yahoo</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="75"/>
        <source>360</source>
        <translation>360</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="76"/>
        <source>360 AI Search</source>
        <translation>360 AI Search</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="77"/>
        <source>Sogou</source>
        <translation>Sogou</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="78"/>
        <source>Custom</source>
        <translation>Прилагодљив</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="99"/>
        <source>You need to use &quot;%0&quot; to replace the keyword in the URL</source>
        <translation>Морате да користите &quot;%0&quot; да замените кључну реч у URL-у</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="167"/>
        <source>Invalid URL</source>
        <translation>Неважећи URL</translation>
    </message>
</context>
<context>
    <name>GrandSearch::StaticTextWorker</name>
    <message>
        <location filename="../src/dde-grand-search-daemon/searcher/web/statictextworker.cpp" line="66"/>
        <source>Search for &quot;%1&quot;</source>
        <translation type="unfinished">Тражи &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>GrandSearch::TailerWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="19"/>
        <source>Tailer settings</source>
        <translation>Подешавања Tailer</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="29"/>
        <source>It is displayed at the end of search results for better identification and distinction of items with duplicate names.</source>
        <translation>Приказано је на крају резултата претраге за боље идентификовање и разликујуће предмете са дубоким именима.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="38"/>
        <source>Parent directory</source>
        <translation>Претходна директоријум</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="40"/>
        <source>Time modified</source>
        <translation>Време измене</translation>
    </message>
</context>
<context>
    <name>GrandSearch::audio_preview::AudioPreviewPlugin</name>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="70"/>
        <source>Artist:</source>
        <translation type="unfinished">Извођач:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="82"/>
        <source>Album:</source>
        <translation type="unfinished">Албум:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="107"/>
        <source>Duration:</source>
        <translation type="unfinished">Трајање:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="122"/>
        <source>Type:</source>
        <translation type="unfinished">Врста:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="134"/>
        <source>Location:</source>
        <translation type="unfinished">Локација:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="148"/>
        <source>Time modified:</source>
        <translation type="unfinished">Измењено:</translation>
    </message>
</context>
<context>
    <name>GrandSearch::image_preview::ImagePreviewPlugin</name>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="65"/>
        <source>Dimensions:</source>
        <translation>Димензије:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="81"/>
        <source>Type:</source>
        <translation type="unfinished">Врста:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="96"/>
        <source>Size:</source>
        <translation type="unfinished">Величина:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="108"/>
        <source>Location:</source>
        <translation type="unfinished">Локација:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="122"/>
        <source>Time modified:</source>
        <translation type="unfinished">Измењено:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="24"/>
        <source>Best match</source>
        <translation>Најбољи поредак</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="25"/>
        <source>Applications</source>
        <translation>Програми</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="26"/>
        <source>Settings</source>
        <translation>Подeшавања</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="27"/>
        <source>Videos</source>
        <translation>Видео</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="28"/>
        <source>Music</source>
        <translation>Музика</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="29"/>
        <source>Pictures</source>
        <translation>Слике</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="30"/>
        <source>Documents</source>
        <translation>Документи</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="31"/>
        <source>Folders</source>
        <translation>Фасцикле</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="32"/>
        <source>Files</source>
        <translation>Датотеке</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="33"/>
        <source>Web</source>
        <translation>Мрежа</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="34"/>
        <source>AI Search</source>
        <translation>AI претрага</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="28"/>
        <source>Dimensions:</source>
        <translation>Dimenzije:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="29"/>
        <source>Type:</source>
        <translation>Врста:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="30"/>
        <source>Size:</source>
        <translation>Величина:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="31"/>
        <source>Duration:</source>
        <translation>Трајање:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="32"/>
        <source>Location:</source>
        <translation>Локација:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="33"/>
        <source>Time modified:</source>
        <translation>Измењено:</translation>
    </message>
    <message>
        <location filename="../src/dde-grand-search-daemon/searcher/file/filesearchutils.cpp" line="205"/>
        <source>modified</source>
        <translation>modifikovano</translation>
    </message>
</context>
<context>
    <name>searchitem</name>
    <message>
        <location filename="../src/grand-search-shell-plugin/package/searchitem.qml" line="24"/>
        <source>GrandSearch</source>
        <translation>GrandSearch</translation>
    </message>
    <message>
        <location filename="../src/grand-search-shell-plugin/package/searchitem.qml" line="81"/>
        <source>SearchConfig</source>
        <translation>SearchConfig</translation>
    </message>
</context>
</TS>
